Solar Production
================

Classes and functions for solar power production calculations.

.. module:: PASS.solar_production

solar_production_classes
------------------------

Solar array modeling classes.

.. automodule:: PASS.solar_production.solar_production_classes
   :members:
   :undoc-members:
   :show-inheritance:

SolarArray
^^^^^^^^^^

.. autoclass:: PASS.solar_production.solar_production_classes.SolarArray
   :members:
   :undoc-members:
   :show-inheritance:

SolarSkirt
^^^^^^^^^^

.. autoclass:: PASS.solar_production.solar_production_classes.SolarSkirt
   :members:
   :undoc-members:
   :show-inheritance:

solar_elevation_angle
---------------------

Functions for calculating solar and lunar elevation angles.

.. automodule:: PASS.solar_production.solar_elevation_angle
   :members:
   :undoc-members:
   :show-inheritance:

optimal_tilt_angle
------------------

Tilt angle optimization functions.

.. automodule:: PASS.solar_production.optimal_tilt_angle
   :members:
   :undoc-members:
   :show-inheritance:
